@@ -32,13 +32,15 @@ class XBRLElement:
         self.uri = uri
         self.label = label
         self.ref = ref
+        self.value = value
 
         # Convert to float to remove any issues with comparing string representations of numbers
         try:
             self.value = float(value)
         except (TypeError, ValueError):
-            logger.info(f"XBRLElement value convert to float failure for {value}")
-            self.value = value
+            if isinstance(value, str):
+                self.value = value.replace('\n', '')
+            logger.info(f"XBRLElement value convert to float failure for {self.value}")
 
         self._children = {}
         self._parent = None
@@ -198,12 +200,16 @@ class XBRLAssembler:
         self.args = args
         self.kwargs = kwargs
 
+
         self.xbrl_elements = {}
 
         # Used for storing data of supporting documents
         self.labels = {}
         self.cells = collections.defaultdict(list)
 
+        self.ref = None
+
+
     @classmethod
     def from_sec_index(cls, index_url, ref_doc=XBRLType.PRE, *args, **kwargs):
         """
@@ -298,12 +304,16 @@ class XBRLAssembler:
 
         if os.path.isfile(file_path):
             with open(file_path, 'r') as file:
-                data = json.load(file)
+                data = {uri: XBRLElement.from_json(dat) for uri, dat in json.load(file).items()}
 
-        data.update({uri: ele.to_json() for uri, ele in self.xbrl_elements.items()})
+        for uri, ele in self.xbrl_elements.items():
+            if uri in data.keys():
+                data[uri].merge(ele)
+            else:
+                data[uri] = ele
 
         with open(file_path, 'w+') as file:
-            json.dump(data, file)
+            json.dump({uri: ele.to_json() for uri, ele in data.items()}, file)
 
     def uri(self, raw):
         """
@@ -364,6 +374,19 @@ class XBRLAssembler:
                               ref=node['contextref'])
             self.cells[uri].append(ele)
 
+    def get_all(self):
+        """
+        A shortcut command to parse all documents against the reference document
+        """
+        for ele in self.xbrl_elements.values():
+            if not ele._children:
+                try:
+                    self.__assemble(ele)
+                except XBRLError as e:
+                    logger.debug(e)
+
+        return self.xbrl_elements
+
     def get(self, search) -> XBRLElement:
         """
         Main access function that will take a variety of search criteria and attempt to create and
@@ -396,10 +419,13 @@ class XBRLAssembler:
         return doc_ele
 
     def __assemble(self, doc_ele):
+        if self.ref is None:
+            return
+
         # Find desired section in reference document
         def_link = self.ref.find(re.compile(r'link', re.IGNORECASE), attrs={'xlink:role': doc_ele.uri})
         if not def_link:
-            raise XBRLError(f"Can't find document in reference doc")
+            raise XBRLError(f"Refernce document doesn't contain any information for {doc_ele.uri}")
 
         # Pull all elements and create XBRLElements out of them
         eles = {}
